# Peertalk

Peertalk is an experimental, demonstrative chat protocol
and implementation for use in Peertable networks. Please
see the Peertable project for more. It's likely to not
work, especially with a larger amount of users.